
# Edlp 8.x Docker Environement
Edlp powered by druapl 8  in docker environement (nginx, php:7-fpm+drush, phpmyadmin, redis)

## Install docker
```
sudo pacman -S docker docker-compose docker-machine
```

## Clone this repos

this will clone this repos (main docker environement) and the edlp drupal 8 source code (without sites/default folder)

```
git clone --recursive -o figli https://figureslibres.io/gogs/bachir/docker-edlp-d8.git
```

### setup /sites/default/settings.php

```cp -r ressources/default public_html/sites/```

### get the sites/default/files folder
get the files from where you have it and rsync it to public_html/sites/default/files/

## Mysql
Copy your-sql-dump.sql into ./ressources/edlp_d8.sql
It will be automaticly imported into the mysql container db (only) on the first docker-compose up

## Hosts and reverse proxy

add to your /etc/hosts :
```
127.0.0.1	dev.encyclopediedelaparole.org
127.0.0.1	dev.phpmyadmin.encyclopediedelaparole.org
```
configure your apache or nginx vhosts to add a reverse proxy that will redirect the dev.encyclopediedelaparole.org to our container

apache
```apache
<Virtualhost *:80>
   ServerName dev.encyclopediedelaparole.org
   ProxyPass / http://127.0.0.1:8880/
   ProxyPassReverse / http://127.0.0.1:8880/
   ProxyRequests Off
</Virtualhost>

<Virtualhost *:80>
   ServerName dev.phpmyadmin.encyclopediedelaparole.org
   ProxyPass / http://127.0.0.1:8881/
   ProxyPassReverse / http://127.0.0.1:8881/
   ProxyRequests Off
</Virtualhost>
```

nginx
```nginx
server {
    listen 80;
    server_name dev.encyclopediedelaparole.org;

    location / {
        proxy_pass http://127.0.0.1:8880;
        proxy_set_header Host $host;
        proxy_set_header X-Real-IP $remote_addr;
        proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
        proxy_set_header X-Forwarded-Proto $scheme;
    }
}

server {
    listen 80;
    server_name dev.phpmyadmin.encyclopediedelaparole.org;

    location / {
        proxy_pass http://127.0.0.1:8881;
        proxy_set_header Host $host;
        proxy_set_header X-Real-IP $remote_addr;
        proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
        proxy_set_header X-Forwarded-Proto $scheme;
    }
}
```


## Docker

### build
only before the first run (may take some time)
```
sudo docker-compose build
```
### run
then each time you want to launch the app
```
sudo docker-compose up -d
```
Be aware that a first up, since the db is empty, it will be populated with your file db.sql. It may take some time depending of your db size.

## Druapal Composer install
Only at first up, finish to install drupal composer dependencies
```
sudo docker exec -it edlpd8_php_1 bash
composer install
```

## Visualize
You can now visit http://dev.encyclopediedelaparole.org on your browser

## Coding
### drush
you can access to drush by loging into the php container
```
sudo docker exec -it edlpd8_php_1 bash
```
once inside the php container in /var/www/html you can use drush as usual

### gulp
Dev process needs gulp to run in:
- public_html/sites/all/modules/figli/edlp_corpus/
- public_html/sites/all/themes/custom/edlptheme/
  if you have to modifie js or scss source code, you need to do in each of these 2 folder:
```
npm install
gulp
```

## updateding manualy mysql db
copy your db backup into the mysql container
```
sudo docker cp your-db-file.sql edlpd8_mysql_1:/root/
```
log into mysql container
```
sudo docker exec -it edlpd8_mysql_1 bash
```
once inside the mysql container you can use mysql command to drop then create and load the db with your file


# sources
https://www.ostraining.com/blog/drupal/docker/

http://tech.osteel.me/posts/2017/01/15/how-to-use-docker-for-local-web-development-an-update.html

https://mmenozzi.github.io/2016/01/22/php-web-development-with-docker/

https://dzone.com/articles/continuous-drupal-maintaining-a-drupal-website-wit//

https://github.com/glaux/drupal8docker

https://www.jeffgeerling.com/blogs/jeff-geerling/drupal-8-redis-php-7-nginx-and

https://chromatichq.com/blog/configuring-redis-caching-drupal-8
